BatchResponse

Struct BatchResponse 

pub struct BatchResponse {
    pub path: String,
    pub body: SmartcarResponseBody,
    pub code: i32,
    pub headers: Option<Meta>,
}
Contains the response body AND metadata of a single endpoint in a batch request

e.g. If you sent a batch request, requesting for endpoints /odometer, /charge, AND /vin, This struct represents the singular response to any of those requests.

Therefore, there will be three of these BatchResponse structs in the response field of the Batch struct. One for Odometer, one for Charge, and one for Vin.

More info on batch

Fields

path: Stringbody: SmartcarResponseBodycode: i32headers: Option<Meta>