pub struct BatchResponse {
pub path: String,
pub body: SmartcarResponseBody,
pub code: i32,
pub headers: Option<Meta>,
}Expand description
Contains the response body AND metadata of a single endpoint in a batch request
e.g. If you sent a batch request, requesting for endpoints /odometer, /charge, AND /vin,
This struct represents the singular response to any of those requests.
Therefore, there will be three of these BatchResponse structs in the response field of the Batch struct. One for Odometer, one for Charge, and one for Vin.
Fields
path: Stringbody: SmartcarResponseBodycode: i32headers: Option<Meta>Trait Implementations
Sourceimpl Debug for BatchResponse
impl Debug for BatchResponse
Sourceimpl<'de> Deserialize<'de> for BatchResponse
impl<'de> Deserialize<'de> for BatchResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more